@@ -11,5 +11,11 @@ if sys.maxsize > 2 ** 32:
             self.assertArgIsOut(CoreML.MLModel.predictionFromFeatures_error_, 1)
             self.assertArgIsOut(CoreML.MLModel.predictionFromFeatures_options_error_, 2)
 
+
+        @min_os_level("10.14")
+        def testMethods10_14(self):
+            self.assertArgIsOut(CoreML.MLModel.modelWithContentsOfURL_configuration_error_, 2)
+            self.assertArgIsOut(CoreML.MLModel.predictionsFromBatch_options_error_, 2)
+
 if __name__ == "__main__":
     main()
